=====
 API
=====

oslo_policy.policy
==================

.. automodule:: oslo_policy.policy
   :members:

.. autoclass:: oslo_policy.policy.AndCheck
.. autoclass:: oslo_policy.policy.NotCheck
.. autoclass:: oslo_policy.policy.OrCheck
.. autoclass:: oslo_policy.policy.RuleCheck

oslo_policy.opts
================

.. automodule:: oslo_policy.opts
   :members:
